% Figure 3 and 4: Ricker wavelet
%
% Random Spectral Sampling Toolbox - Roel Snieder and Michael B. Wakin
% Version 1.0 - March 23, 2022
% See README.txt

clear all; close all;
N = 600;

% Time indices
t = [-N/2:N/2-1]';

% Construct Ricker wavelet in time domain
tau = 10;
t0 = 0;
ricker = (1 - 2*((t-t0)/tau).^2 ).*exp( - ((t-t0)/tau).^2 );

% Randomly subsample spectrum by factor of 3 without replacement
ricker_rand = subsampleSpectrum(ricker,N/3,1);

% Create figures
figure(3);clf;
set(gcf,'color','white')
box on
plot(t,ricker,'k','LineWidth',2)
axis( [-300 300 -0.5 1.05]);
xlabel('time (s)','FontSize',18);
set(gca,'xTick',-200:100:200,'FontSize',18)
set(gca,'yTick',-0.4:0.2:1,'FontSize',18)
% print('fig3','-dpng')

figure(4); clf;
set(gcf,'color','white')
box on
plot(t,ricker,'k','LineWidth',2)
hold on
plot(t, real(ricker_rand),'b','LineWidth',2)
plot(t, imag(ricker_rand),'r','LineWidth',2)
axis( [-300 300 -0.5 1.05]);
xlabel('time (s)','FontSize',18);
set(gca,'xTick',-200:100:200,'FontSize',18)
set(gca,'yTick',-0.4:0.2:1,'FontSize',18)
legend('original','real part','imaginary part','FontSize',18)
% print('fig4','-dpng')

% Compute standard deviation of estimation error
sigma = sqrt(sum(abs(ricker-ricker_rand).^2)/(N))

